@@ -20,6 +20,10 @@ import xmlrpc.client
 
 from pyrois import RoIS_Common, RoIS_HRI, IF_server
 
+if sys.version_info.major == 2:
+    import Queue as queue
+else:
+    import queue
 
 class Command(RoIS_Common.Command):
     """Command
