@@ -470,7 +470,7 @@ class Execute_test(unittest.TestCase):
             else:
                 pass
         
-        print("completed_command_id:{}".format(completed_command_id))
+        # print("completed_command_id:{}".format(completed_command_id))
         
         command_unit_lists = [command_unit_list1]
         command_ids = set()
